function DraconisErus_Guild_IsOfficer(player)
	local retVal = false
	local inGuild, guildRank = DraconisErus_Guild_HasPlayer(player)
	if inGuild then
		if (guildRank >=0 and guildRank <=3) then
			retVal = true
		end
	end
	return retVal
end

function DraconisErus_Guild_FindOfficers()
	local officers = {}
	local guildSize,_,_ = GetNumGuildMembers()
	for i=1, tonumber(guildSize) do
		name,_,rank,level,_,_,_,_,online = GetGuildRosterInfo(i)
		if name ~= "" and name ~= nil then
			name = DraconisErus_FixName(name)
			if ((rank >= 0 and rank <=3) and online) then
				table.insert(officers,name)
			end
		end
	end
	return officers
end

function DraconisErus_Guild_HasPlayer(player)
	local inGuild = false
	local guildRank = -1
	local guildSize,_,_ = GetNumGuildMembers()
	for i=1, tonumber(guildSize) do
		name,_,rank,level = GetGuildRosterInfo(i)
		if name ~= "" and name ~= nil then
			name = DraconisErus_FixName(name)
			if name == player then
				inGuild = true
				guildRank = rank
				break
			end
		end
	end
	return inGuild, guildRank
end

function DraconisErus_Guild_Save(lplayer, llevel)
	if (lplayer == nil) and (GetServerTime() - DERR_LAST_GUILD_ROSTER < 60) then return end
	DERR_LAST_GUILD_ROSTER = GetServerTime()
	if DEDKPGuilds["Saves"] == nil then
		DEDKPGuilds = {}
		DEDKPGuilds[DERR_REALM] = {}
		DEDKPGuilds[DERR_REALM][DERR_GUILD] = {}
		DEDKPGuilds["Saves"] = {} 
	end
	if DEDKPGuilds["Saves"][DERR_REALM] == nil then DEDKPGuilds["Saves"][DERR_REALM] = {} end
	DEDKPGuilds["Saves"][DERR_REALM][DERR_GUILD] = GetServerTime()
	DEDKPGuilds[DERR_REALM][DERR_GUILD] = {}
	local guildSize,_,_ = GetNumGuildMembers()
	DraconisErus_Debug("Guild Size: "..guildSize)
	for i=1, tonumber(guildSize) do
		local name, rank, rankIndex, level, _, _, _, _, _, _, class  = GetGuildRosterInfo(i)
		if name ~= "" and name ~= nil then
			name = DraconisErus_FixName(name)
			if name == lplayer then
				level = llevel
			end

			local playerdata = {["name"] = name, ["rank"] = rank, ["rankindex"] = rankIndex, ["level"] = level, ["class"] = class }
			table.insert(DEDKPGuilds[DERR_REALM][DERR_GUILD],playerdata)
		end
	end
	DraconisErus_Debug("Guild Saved.")
end

function DraconisErus_Guild_GetEmptyPoints()
	local retVal = {}
	local guildSize,_,_ = GetNumGuildMembers()
	for i=1, tonumber(guildSize) do
		name, rank = GetGuildRosterInfo(i)
		if name ~= "" and name ~= nil then
			name = DraconisErus_FixName(name)
			retVal[name] = 0
		end
	end
	return retVal
end

function DraconisErus_Guild_GetRaiders()
	local raiders = {}
	local guildSize,_,_ = GetNumGuildMembers()
	for i=1, tonumber(guildSize) do
		local gname,_,_,glevel,_,_,_,_,_,_,gclass = GetGuildRosterInfo(i)
		if gname ~= "" and gname ~= nil then
			gname = DraconisErus_FixName(gname)
			local gpoints = 0
			if DEDKPPoints[DERR_REALM][DERR_GUILD][gname] ~= nil then gpoints = DEDKPPoints[DERR_REALM][DERR_GUILD][gname] end
			if glevel >= 55 then
				table.insert(raiders, { name = gname, class = gclass, points = gpoints })
			end
		end
	end
	return raiders
end

function DraconisErus_SortRaidersByName(raiders)
	table.sort(raiders, function(a, b)
	    	return a.name < b.name
  	end)
end

function DraconisErus_SortRaidersByPoints(raiders)
	table.sort(raiders, function(a, b)
		if a.points ~= b.points then
			return a.points > b.points
		end
		return a.name < b.name
  	end)
end

function DraconisErus_Guild_GetClass(player)
	local className = ""
	local guildSize,_,_ = GetNumGuildMembers()
	for i=1, tonumber(guildSize) do
		name,_,_,_,_,_,_,_,_,_,class = GetGuildRosterInfo(i)
		if name ~= "" and name ~= nil then
			name = DraconisErus_FixName(name)
			if name == player then
				className = class
				break
			end
		end
	end
	return className
end

function DraconisErus_Guild_GetLevel(player)
	local playerlevel = 0
	local guildSize,_,_ = GetNumGuildMembers()
	for i=1, tonumber(guildSize) do
		name,_,_,level = GetGuildRosterInfo(i)
		if name ~= "" and name ~= nil then
			name = DraconisErus_FixName(name)
			if name == player then
				playerlevel = level
				break
			end
		end
	end
	return playerlevel
end

function DraconisErus_Guild_RequestPoints()
	local officers = DraconisErus_Guild_FindOfficers()
	if table.getn(officers) > 0 then
		for index, value in pairs(officers) do
			if value ~= DERR_PLAYER then
				DraconisErus_Comm_Send("DERRSENDDKP","","WHISPER",value)
				break
			end
		end
	end
end
